<?php

namespace Payroll\Company\Http\Controllers;
use Litepie\Company\Http\Requests\CompanyRequest;
use Litepie\Company\Models\Company;

trait CompanyWorkflow {
	
    /**
     * Workflow controller function for company.
     *
     * @param Model   $company
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CompanyRequest $request, Company $company, $step)
    {

        try {

            $company->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('company::company.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/company/company/' . $company->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/company/company/' . $company->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for company.
     *
     * @param Model   $company
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Company $company, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $company->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('company::company.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company::admin.company.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company::admin.company.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company::admin.company.message', $data)->render();

        }

    }
}