<?php

namespace Payroll\Company\Policies;

use App\User;
use Payroll\Company\Models\Company;

class CompanyPolicy
{

    /**
     * Determine if the given user can view the company.
     *
     * @param User $user
     * @param Company $company
     *
     * @return bool
     */
    public function view(User $user, Company $company)
    {
        if ($user->canDo('company.company.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $company->user_id;
    }

    /**
     * Determine if the given user can create a company.
     *
     * @param User $user
     * @param Company $company
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('company.company.create');
    }

    /**
     * Determine if the given user can update the given company.
     *
     * @param User $user
     * @param Company $company
     *
     * @return bool
     */
    public function update(User $user, Company $company)
    {
        if ($user->canDo('company.company.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $company->user_id;
    }

    /**
     * Determine if the given user can delete the given company.
     *
     * @param User $user
     * @param Company $company
     *
     * @return bool
     */
    public function destroy(User $user, Company $company)
    {
        if ($user->canDo('company.company.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $company->user_id;
    }

    /**
     * Determine if the given user can verify the given company.
     *
     * @param User $user
     * @param Company $company
     *
     * @return bool
     */
    public function verify(User $user, Company $company)
    {
        if ($user->canDo('company.company.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('company.company.verify') 
        && $user->is('manager')
        && $company->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given company.
     *
     * @param User $user
     * @param Company $company
     *
     * @return bool
     */
    public function approve(User $user, Company $company)
    {
        if ($user->canDo('company.company.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
