<?php

namespace Payroll\Company\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Payroll\Company\Models\Company;

class CompanyAction
{
    /**
     * Perform the complete action.
     *
     * @param Company $company
     *
     * @return Company
     */
    public function complete(Company $company)
    {
        try {
            $company->status = 'complete';
            return $company->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Company $company
     *
     * @return Company
     */public function verify(Company $company)
    {
        try {
            $company->status = 'verify';
            return $company->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Company $company
     *
     * @return Company
     */public function approve(Company $company)
    {
        try {
            $company->status = 'approve';
            return $company->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Company $company
     *
     * @return Company
     */public function publish(Company $company)
    {
        try {
            $company->status = 'publish';
            return $company->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Company $company
     *
     * @return Company
     */
    public function archive(Company $company)
    {
        try {
            $company->status = 'archive';
            return $company->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Company $company
     *
     * @return Company
     */
    public function unpublish(Company $company)
    {
        try {
            $company->status = 'unpublish';
            return $company->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
