<?php

namespace Payroll\Company\Workflow;

use Payroll\Company\Models\Company;
use Validator;

class CompanyValidator
{

    /**
     * Determine if the given company is valid for complete status.
     *
     * @param Company $company
     *
     * @return bool / Validator
     */
    public function complete(Company $company)
    {
        return Validator::make($company->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given company is valid for verify status.
     *
     * @param Company $company
     *
     * @return bool / Validator
     */
    public function verify(Company $company)
    {
        return Validator::make($company->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given company is valid for approve status.
     *
     * @param Company $company
     *
     * @return bool / Validator
     */
    public function approve(Company $company)
    {
        return Validator::make($company->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given company is valid for publish status.
     *
     * @param Company $company
     *
     * @return bool / Validator
     */
    public function publish(Company $company)
    {
        return Validator::make($company->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given company is valid for archive status.
     *
     * @param Company $company
     *
     * @return bool / Validator
     */
    public function archive(Company $company)
    {
        return Validator::make($company->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given company is valid for unpublish status.
     *
     * @param Company $company
     *
     * @return bool / Validator
     */
    public function unpublish(Company $company)
    {
        return Validator::make($company->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
